@@ -1,4 +1,4 @@
-# Copyrights 2011-2013 by [Mark Overmeer].
+# Copyrights 2011-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,16 +7,17 @@ use strict;
 
 package POSIX::1003;
 use vars '$VERSION';
-$VERSION = '0.98';
+$VERSION = '0.99_01';
 
 
 use Carp qw/croak/;
+use POSIX::1003::Module ();   # preload
 
 my %own_functions = map +($_ => 1), qw/
-  posix_1003_modules
-  posix_1003_names
-  show_posix_names
- /;
+    posix_1003_modules
+    posix_1003_names
+    show_posix_names
+   /;
 
 our (%EXPORT_TAGS, %IMPORT_FROM, %SUBSET);
 
@@ -51,6 +52,7 @@ my %tags =
   , sigaction =>   'POSIX::SigAction'
   , signals =>     [qw/POSIX::1003::Signals POSIX::SigSet POSIX::SigAction/]
   , sigset =>      'POSIX::SigSet'
+  , socket =>      'POSIX::1003::Socket'
   , sysconf =>     'POSIX::1003::Sysconf'
   , termio =>      'POSIX::1003::Termios'
   , termios =>     'POSIX::1003::Termios'
@@ -213,5 +215,6 @@ sub show_posix_names(@)
     print "*** ".(keys %$pkg_of)." symbols in total\n";
 }
 
+#------------
 
 1;
