@@ -1,4 +1,4 @@
-# Copyrights 2011-2013 by [Mark Overmeer].
+# Copyrights 2011-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,21 +7,18 @@ use strict;
 
 package POSIX::1003::FS;
 use vars '$VERSION';
-$VERSION = '0.98';
+$VERSION = '0.99_01';
 
 use base 'POSIX::1003::Module';
 
 # Blocks resp from unistd.h, stdio.h, limits.h
 my @constants;
 my @access = qw/access/;
-
-my @stat  = qw/stat lstat
-  S_ISDIR S_ISCHR S_ISBLK S_ISREG S_ISFIFO S_ISLNK S_ISSOCK S_ISWHT S_IFMT
-  S_IFBLK S_IFCHR S_IFDIR S_IFIFO S_IFLNK S_IFMT S_IFREG S_IFSOCK S_ISGID
-  S_ISUID S_ISVTX/;
-
-my @perms = qw/S_IRGRP S_IROTH S_IRUSR S_IRWXG S_IRWXO S_IRWXU
-  S_IWGRP S_IWOTH S_IWUSR S_IXGRP S_IXOTH S_IXUSR/;
+my @stat   = qw/stat lstat/;
+my @perms  = qw/mkfifo mknod mkdir lchown
+  S_ISDIR S_ISCHR S_ISBLK S_ISREG S_ISFIFO S_ISLNK S_ISSOCK S_ISWHT
+/;
+my @glob;  # qw/glob fnmatch/;
 
 sub S_ISDIR($)  { ($_[0] & S_IFMT()) == S_IFDIR()}
 sub S_ISCHR($)  { ($_[0] & S_IFMT()) == S_IFCHR()}
@@ -49,27 +46,40 @@ our %EXPORT_TAGS =
  , functions => \@functions
  , access    => \@access
  , stat      => \@stat
+ , glob      => \@glob
  , tables    => [ qw/%access %stat/ ]
  , perms     => \@perms
  );
 
-my ($fsys, %access, %stat);
+my ($fsys, %access, %stat, %glob, %perms);
 
 BEGIN {
     $fsys = fsys_table;
-    push @constants, keys %$fsys;
+    push @constants, grep !/^S_IS/, keys %$fsys;
 
     # initialize the :access export tag
-    push @access, grep /_OK$/, keys %$fsys;
+    push @access, grep /_OK$|MAX/, keys %$fsys;
     my %access_subset;
     @access_subset{@access} = @{$fsys}{@access};
     tie %access,  'POSIX::1003::ReadOnlyTable', \%access_subset;
 
-    # initialize the :fsys export tag
+    # initialize the :stat export tag
     push @stat, grep /^S_/, keys %$fsys;
     my %stat_subset;
     @stat_subset{@stat} = @{$fsys}{@stat};
     tie %stat, 'POSIX::1003::ReadOnlyTable', \%stat_subset;
+
+    # initialize the :perms export tag
+    push @perms, grep /^S_I[^S]/, keys %$fsys;
+    my %perms_subset;
+    @perms_subset{@perms} = @{$fsys}{@perms};
+    tie %perms, 'POSIX::1003::ReadOnlyTable', \%perms_subset;
+ 
+    # initialize the :fsys export tag
+    push @glob, grep /^(?:GLOB|FNM)_/, keys %$fsys;
+    my %glob_subset;
+    @glob_subset{@glob} = @{$fsys}{@glob};
+    tie %glob, 'POSIX::1003::ReadOnlyTable', \%glob_subset;
 }
 
 
