@@ -1,4 +1,4 @@
-# Copyrights 2011-2013 by [Mark Overmeer].
+# Copyrights 2011-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,7 +7,7 @@ use strict;
 
 package POSIX::1003::Fcntl;
 use vars '$VERSION';
-$VERSION = '0.98';
+$VERSION = '0.99_01';
 
 use base 'POSIX::1003::Module';
 
@@ -47,11 +47,12 @@ our %EXPORT_TAGS =
  , tables    => [ qw/%fcntl/ ]
  );
 
-our @IN_CORE  = qw/
-fcntl
-flock/;
+our @IN_CORE  = qw/fcntl flock/;
 
 my $fcntl;
+
+# We need to address all of our own constants via this HASH, because
+# they will not be available at compile-time of this file.
 our %fcntl;
 
 BEGIN {
@@ -60,40 +61,9 @@ BEGIN {
     tie %fcntl,  'POSIX::1003::ReadOnlyTable', $fcntl;
 }
 
+# required parameter which does not get used by the OS.
 use constant UNUSED => 0;
 
-# We need to have these values, but get into a chicked-egg problem with
-# the normal import() procedure.
-use constant
- { F_DUPFD      => $fcntl->{F_DUPFD}
- , F_DUPFD_CLOEXEC => $fcntl->{F_DUPFD_CLOEXEC}
- , F_GETFD      => $fcntl->{F_GETFD}
- , F_GETFL      => $fcntl->{F_GETFL}
- , F_GETLCK     => $fcntl->{F_GETLCK}
- , F_GETLEASE   => $fcntl->{F_GETLEASE}
- , F_GETLK      => $fcntl->{F_GETLK}
- , F_GETLKW     => $fcntl->{F_GETLKW}
- , F_GETOWN     => $fcntl->{F_GETOWN}
- , F_GETOWN_EX  => $fcntl->{F_GETOWN_EX}
- , F_GETPIPE_SZ => $fcntl->{F_GETPIPE_SZ}
- , F_GETSIG     => $fcntl->{F_GETSIG}
- , F_NOTIFY     => $fcntl->{F_NOTIFY}
- , F_OWNER_PGRP => $fcntl->{F_OWNER_PGRP}
- , F_OWNER_PID  => $fcntl->{F_OWNER_PID}
- , F_RDLCK      => $fcntl->{F_RDLCK}
- , F_SETFD      => $fcntl->{F_SETFD}
- , F_SETFL      => $fcntl->{F_SETFL}
- , F_SETLEASE   => $fcntl->{F_SETLEASE}
- , F_SETLK      => $fcntl->{F_SETLK}
- , F_SETLKW     => $fcntl->{F_SETLKW}
- , F_SETOWN     => $fcntl->{F_SETOWN}
- , F_SETOWN_EX  => $fcntl->{F_SETOWN_EX}
- , F_SETPIPE_SZ => $fcntl->{F_SETPIPE_SZ}
- , F_SETSIG     => $fcntl->{F_SETSIG}
- , F_UNLCK      => $fcntl->{F_UNLCK}
- , F_WRLCK      => $fcntl->{F_WRLCK}
- };
-
 
 sub flockfd($$)
 {   my ($file, $flags) = @_;
@@ -112,15 +82,15 @@ sub lockf($$;$)
 sub fcntl_dup($%)
 {   my ($file, %args) = @_;
     my $fd   = ref $file ? fileno($file) : $file;
-    my $func = $args{close_on_exec} ? F_DUPFD_CLOEXEC : F_DUPFD;
+    my $func = $args{close_on_exec} ? $fcntl->{F_DUPFD_CLOEXEC} : $fcntl->{F_DUPFD};
 
-    return _fcntl $fd, F_DUPFD, UNUSED
+    return _fcntl $fd, $fcntl->{F_DUPFD}, UNUSED
         if !$args{close_on_exec};
 
-    return _fcntl $fd, F_DUPFD_CLOEXEC, UNUSED
-        if defined F_DUPFD_CLOEXEC;
+    return _fcntl $fd, $fcntl->{F_DUPFD_CLOEXEC}, UNUSED
+        if defined $fcntl->{F_DUPFD_CLOEXEC};
 
-    _fcntl $fd, F_DUPFD, UNUSED;
+    _fcntl $fd, $fcntl->{F_DUPFD}, UNUSED;
     setfd_control $fd, O_CLOEXEC;
 }
 
@@ -128,36 +98,42 @@ sub fcntl_dup($%)
 sub getfd_control($)
 {   my ($file) = @_;
     my $fd   = ref $file ? fileno($file) : $file;
-    _fcntl $fd, F_GETFD, UNUSED;
+    _fcntl $fd, $fcntl->{F_GETFD}, UNUSED;
 }
 
 
 sub setfd_control($$)
 {   my ($file, $flags) = @_;
     my $fd   = ref $file ? fileno($file) : $file;
-    _fcntl $fd, F_SETFD, $flags;
+    _fcntl $fd, $fcntl->{F_SETFD}, $flags;
 }
 
 
 sub getfd_flags($)
 {   my ($file) = @_;
     my $fd   = ref $file ? fileno($file) : $file;
-    _fcntl $fd, F_GETFL, UNUSED;
+    _fcntl $fd, $fcntl->{F_GETFL}, UNUSED;
 }
 
 
 sub setfd_flags($$)
 {   my ($file, $flags) = @_;
     my $fd   = ref $file ? fileno($file) : $file;
-    _fcntl $fd, F_SETFL, $flags;
+    _fcntl $fd, $fcntl->{F_SETFL}, $flags;
 }
 
 
 sub setfd_lock($%)
 {   my ($file, %args) = @_;
     my $fd   = ref $file ? fileno($file) : $file;
-    my $func = $args{wait} ? F_SETLK : F_SETLKW;
-    $args{type}   //= F_RDLCK;
+
+    my $func;
+    $func   = $args{wait} ? $fcntl->{F_SETLKP} : $fcntl->{F_SETLKWP}
+        if $args{private};
+
+    $func //= $args{wait} ? $fcntl->{F_SETLK}  : $fcntl->{F_SETLKW};
+
+    $args{type}   //= $fcntl->{F_RDLCK};
     $args{whence} //= SEEK_SET;
     $args{start}  //= 0;
     $args{len}    //= 0;
@@ -168,15 +144,17 @@ sub setfd_lock($%)
 sub getfd_islocked($%)
 {   my ($file, %args) = @_;
     my $fd   = ref $file ? fileno($file) : $file;
-    $args{type}   //= F_RDLCK;
+    $args{type}   //= $fcntl->{F_RDLCK};
     $args{whence} //= SEEK_SET;
     $args{start}  //= 0;
     $args{len}    //= 0;
-    my $lock = _lock $fd, F_GETLK, \%args
+
+    my $func = $args{private} ? ($fcntl->{F_GETLKW}//$fcntl->{F_GETLK}) : $fcntl->{F_GETLK};
+    my $lock = _lock $fd, $func, \%args
        or return undef;
 
     #XXX MO: how to represent "ENOSYS"?
-    $lock->{type}==F_UNLCK ? undef : $lock;
+    $lock->{type}==$fcntl->{F_UNLCK} ? undef : $lock;
 }
 
 
@@ -184,15 +162,15 @@ sub getfd_owner($%)
 {   my ($file, %args) = @_;
     my $fd   = ref $file ? fileno($file) : $file;
 
-    my ($type, $pid) = _own_ex $fd, F_GETOWN_EX, UNUSED, UNUSED;
+    my ($type, $pid) = _own_ex $fd, $fcntl->{F_GETOWN_EX}, UNUSED, UNUSED;
     unless(defined $type && $!==ENOSYS)
-    {   $pid = _fcntl $fd, F_GETOWN, UNUSED;
+    {   $pid = _fcntl $fd, $fcntl->{F_GETOWN}, UNUSED;
         if($pid < 0)
         {   $pid  = -$pid;
-            $type = F_OWNER_PGRP // 2;
+            $type = $fcntl->{F_OWNER_PGRP} // 2;
         }
         else
-        {   $type = F_OWNER_PID  // 1;
+        {   $type = $fcntl->{F_OWNER_PID}  // 1;
         }
     }
 
@@ -205,14 +183,14 @@ sub setfd_owner($$%)
     my $fd   = ref $file ? fileno($file) : $file;
 
     my $type = $args{type}
-            || ($pid < 0 ? (F_OWNER_PGRP//2) : (F_OWNER_PID//1));
+            || ($pid < 0 ? ($fcntl->{F_OWNER_PGRP}//2) : ($fcntl->{F_OWNER_PID}//1));
 
     $pid     = -$pid if $pid < 0;
 
-    my ($t, $p) = _own_ex $fd, F_SETOWN_EX, $pid, $type;
+    my ($t, $p) = _own_ex $fd, $fcntl->{F_SETOWN_EX}, $pid, $type;
     unless($t && $!==ENOSYS)
-    {   my $sig_pid = $type==(F_OWNER_PGRP//2) ? -$pid : $pid;
-        ($t, $p) = _fcntl $fd, F_SETOWN, $pid;
+    {   my $sig_pid = $type==($fcntl->{F_OWNER_PGRP}//2) ? -$pid : $pid;
+        ($t, $p) = _fcntl $fd, $fcntl->{F_SETOWN}, $pid;
     }
 
     defined $t;
@@ -222,28 +200,28 @@ sub setfd_owner($$%)
 sub setfd_signal($$)
 {   my ($file, $signal) = @_;
     my $fd   = ref $file ? fileno($file) : $file;
-    _fcntl $fd, F_SETSIG, $signal;
+    _fcntl $fd, $fcntl->{F_SETSIG}, $signal;
 }
 
 
 sub getfd_signal($)
 {   my $file = shift;
     my $fd   = ref $file ? fileno($file) : $file;
-    _fcntl $fd, F_SETSIG, UNUSED;
+    _fcntl $fd, $fcntl->{F_SETSIG}, UNUSED;
 }
 
 
 sub setfd_lease($$)
 {   my ($file, $flags) = @_;
     my $fd   = ref $file ? fileno($file) : $file;
-    _fcntl $fd, F_SETLEASE, $flags;
+    _fcntl $fd, $fcntl->{F_SETLEASE}, $flags;
 }
 
 
 sub getfd_lease($)
 {   my $file = shift;
     my $fd   = ref $file ? fileno($file) : $file;
-    _fcntl $fd, F_GETLEASE, UNUSED;
+    _fcntl $fd, $fcntl->{F_GETLEASE}, UNUSED;
 }
 
 
@@ -251,21 +229,21 @@ sub getfd_lease($)
 sub setfd_notify($$)
 {   my ($dir, $flags) = @_;
     my $fd   = ref $dir ? fileno($dir) : $dir;
-    _fcntl $fd, F_NOTIFY, $flags;
+    _fcntl $fd, $fcntl->{F_NOTIFY}, $flags;
 }
 
 
 sub setfd_pipe_size($$)
 {   my ($file, $size) = @_;
     my $fd   = ref $file ? fileno($file) : $file;
-    _fcntl $fd, F_SETPIPE_SZ, $size;
+    _fcntl $fd, $fcntl->{F_SETPIPE_SZ}, $size;
 }
 
 
 sub getfd_pipe_size($)
 {   my $file = shift;
     my $fd   = ref $file ? fileno($file) : $file;
-    _fcntl $fd, F_GETPIPE_SZ, UNUSED;
+    _fcntl $fd, $fcntl->{F_GETPIPE_SZ}, UNUSED;
 }
 
 
