@@ -1,4 +1,4 @@
-# Copyrights 2011-2013 by [Mark Overmeer].
+# Copyrights 2011-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,24 +7,37 @@ use strict;
 
 package POSIX::1003::Locale;
 use vars '$VERSION';
-$VERSION = '0.98';
+$VERSION = '0.99_01';
 
 use base 'POSIX::1003::Module';
 
 # Blocks from resp. limits.h and local.h
-my @constants = qw/
-  MB_LEN_MAX
-
-  LC_ALL LC_COLLATE LC_CTYPE LC_MESSAGES LC_MONETARY LC_NUMERIC
-  LC_TIME
- /;
-
+my @constants;
 my @functions = qw/localeconv setlocale/;
 
 our %EXPORT_TAGS =
   ( constants => \@constants
   , functions => \@functions
+  , tables    => [ '%locale' ]
   );
 
+my  $locale;
+our %locale;
+
+BEGIN {
+    $locale = locale_table;
+    push @constants, keys %$locale;
+    tie %locale, 'POSIX::1003::ReadOnlyTable', $locale;
+}
+
+
+
+
+sub _create_constant($)
+{   my ($class, $name) = @_;
+    my $val = $locale->{$name};
+    sub () {$val};
+}
+
 
 1;
