@@ -1,4 +1,4 @@
-# Copyrights 2011-2013 by [Mark Overmeer].
+# Copyrights 2011-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,45 +7,20 @@ use warnings;
 
 package POSIX::1003::Module;
 use vars '$VERSION';
-$VERSION = '0.98';
+$VERSION = '0.99_01';
 
 
 # The VERSION of the distribution is sourced from this file, because
 # this module also loads the XS extension.
-our $VERSION = '0.98';
+our $VERSION = '0.99_01';
 use Carp 'croak';
 
-{ use XSLoader;
-  no warnings 'redefine';
-  XSLoader::load 'POSIX';
-  XSLoader::load 'POSIX::1003', $VERSION;
-}
+# some other modules used by the program which uses POSIX::1003 may
+# need POSIX.xs via POSIX.
+use POSIX ();
 
-# also used in release-test
-our $in_constant_table = qr/
-   ^_CS_    # confstr
- | ^DN_     # fcntl
- | ^E(?!CHONL|XIT_) # errno   ECHONL in Termios, EXIT_ in Proc
- | ^FCNTL   # fcntl
- | ^F_      # fcntl
- | ^FD_     # fcntl
- | ^GET_    # rlimit
- | ^LOCK_   # fcntl
- | ^O_      # fdio
- | ^_PC_    # pathconf
- | ^POLL    # poll
- | ^_POSIX  # property
- | ^RLIM    # rlimit
- | ^SA_     # sigaction
- | ^S_      # stat
- | ^_SC_    # sysconf
- | ^SEEK_   # fdio
- | ^SET_    # rlimit aix
- | ^SIG[^_] # signals
- | ^UL_     # ulimit
- | ^WSAE    # errno (windows sockets)
- | _OK$     # access
- /x;
+use XSLoader;
+XSLoader::load 'POSIX::1003', $VERSION;
 
 
 sub import(@)
@@ -78,7 +53,7 @@ sub import(@)
             @take{@$tag} = ();
         }
         else
-        {   $_ =~ $in_constant_table or exists $ok->{$_}
+        {   is_missing($_) or exists $ok->{$_}
                or croak "$class does not export $_";
             undef $take{$_};
         }
@@ -93,7 +68,8 @@ sub import(@)
         {   # reuse the already created function; might also be a function
             # which is actually implemented in the $class namespace.
         }
-        elsif($f =~ $in_constant_table)
+        elsif(   is_missing($f)
+              || (exists $ok->{$f} && $f =~ /^[A-Z_][A-Z0-9_]*$/))
         {   *{$class.'::'.$f} = $export = $class->_create_constant($f);
         }
         elsif( $f !~ m/[^A-Z0-9_]/ )  # faster than: $f =~ m!^[A-Z0-9_]+$!
@@ -110,10 +86,6 @@ sub import(@)
                 *{$class.'::'.$f} = $export = sub() {undef};
             }
         }
-        elsif(exists $POSIX::{$f} && defined *{"POSIX::$f"}{CODE})
-        {   # normal functions implemented in POSIX.xs
-            *{"${class}::$f"} = $export = *{"POSIX::$f"}{CODE};
-        }
         elsif($f =~ s/^%//)
         {   $export = \%{"${class}::$f"};
         }
@@ -121,6 +93,10 @@ sub import(@)
         {   # function is in core, simply ignore the export
             next;
         }
+        elsif(exists $POSIX::{$f} && defined *{"POSIX::$f"}{CODE})
+        {   # normal functions implemented in POSIX.xs
+            *{"${class}::$f"} = $export = *{"POSIX::$f"}{CODE};
+        }
         else
         {   croak "unable to load $f from $class";
         }
@@ -140,13 +116,13 @@ sub exampleValue($)
     grep $_ eq $name, @$constants
         or return undef;
 
-    my $val = &{"$pkg\::$name"};
+    my $val = $pkg->_create_constant($name)->();
     defined $val ? $val : 'undef';
 }
 
 package POSIX::1003::ReadOnlyTable;
 use vars '$VERSION';
-$VERSION = '0.98';
+$VERSION = '0.99_01';
 
 sub TIEHASH($) { bless $_[1], $_[0] }
 sub FETCH($)   { $_[0]->{$_[1]} }
