@@ -1,4 +1,4 @@
-# Copyrights 2011-2013 by [Mark Overmeer].
+# Copyrights 2011-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,7 +7,7 @@ use strict;
 
 package POSIX::1003::Termios;
 use vars '$VERSION';
-$VERSION = '0.98';
+$VERSION = '0.99_01';
 
 use base 'POSIX::1003::Module', 'POSIX::Termios';
 
@@ -43,4 +43,11 @@ our %EXPORT_TAGS =
  );
 
 
+# Only needed by manual.PL
+sub _create_constant($)
+{   my ($class, $name) = @_;
+    no strict 'refs';
+    sub { &{"POSIX::$name"} };
+}
+
 1;
