@@ -1,4 +1,4 @@
-# Copyrights 2011-2013 by [Mark Overmeer].
+# Copyrights 2011-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,13 +7,10 @@ use strict;
 
 package POSIX::1003::User;
 use vars '$VERSION';
-$VERSION = '0.98';
+$VERSION = '0.99_01';
 
 use base 'POSIX::1003::Module';
 
-my @constants = qw/
- /;
-
 our @IN_CORE  = qw/
   getpwnam  getpwuid  getpwent
   getgrnam  getgrgid  getgrent
@@ -35,11 +32,23 @@ my @functions = qw/
 
 push @functions, @IN_CORE;
 
+my @constants;
+
 our %EXPORT_TAGS =
   ( constants => \@constants
   , functions => \@functions
+  , tables    => [ '%user' ]
   );
 
+my  $user;
+our %user;
+
+BEGIN {
+    $user = user_table;
+    push @constants, keys %$user;
+    tie %user, 'POSIX::1003::ReadOnlyTable', $user;
+}
+
 
 #------------------
 
